'use strict';
let inquirer = require('inquirer');
let async = require('async');
let evaluate = require('./evaluate.js');

let promptMapping = {
    string: 'input',
    boolean: 'confirm'
};

/*
 * handle prompts
 */

module.exports = function ask (prompts, data, done) {
    //console.log(prompts);
    if(prompts && Object.keys(prompts)) {
        async.eachSeries(Object.keys(prompts), (key, next) => {
            prompt(data, key, prompts[key], next);
        }, done);
    }else {
        done();
    }
};

function prompt (data, key, prompt, done) {
    // skip prompts whose when condition is not met
    if (prompt.when && !evaluate(prompt.when, data)) {
        return done();
    }
    inquirer.prompt([{
        type: promptMapping[prompt.type] || prompt.type,
        name: key,
        message: prompt.message || prompt.label || key,
        default: prompt.default,
        choices: prompt.choices || [],
        validate: prompt.validate || function () { return true; }
    }]).then((answers) => {
        if (Array.isArray(answers[key])) {
            data[key] = {};
            answers[key].forEach(function (multiChoiceAnswer) {
                data[key][multiChoiceAnswer] = true;
            });
        } else {
            data[key] = answers[key];
        }
        done();
    });
}