'use strict';
let path = require('path');
let metadata = require('read-metadata');
let exists = require('fs').existsSync;
let getGitUser = require('./git-user');

/**
 * Read prompts metadata.
 *
 * @param {String} dir
 * @return {Object}
 */

module.exports = function options (name, dir) {
    var opts = getMetadata(dir);

    opts.prompts && setDefault(opts, 'name', name);

    var author = getGitUser();
    if (author && opts.prompts) {
        setDefault(opts, 'author', author);
    }

    return opts;
};

/**
 * Gets the metadata from either a meta.json or meta.js file.
 *
 * @param  {String} dir
 * @return {Object}
 */

function getMetadata (dir) {
    var json = path.join(dir, 'meta.json');
    var js = path.join(dir, 'meta.js');
    var opts = {};

    if (exists(json)) {
        opts = metadata.sync(json);
    } else if (exists(js)) {
        var req = require(path.resolve(js));
        if (req !== Object(req)) {
            throw new Error('meta.js needs to expose an object');
        }
        opts = req;
    }

    return opts;
}

/**
 * Set the default value for a prompt question
 *
 * @param {Object} opts
 * @param {String} key
 * @param {String} val
 */

function setDefault (opts, key, val) {
    if (opts.schema) {
        opts.prompts = opts.schema;
        delete opts.schema;
    }
    var prompts = opts.prompts || (opts.prompts = {});
    if (!prompts[key] || typeof prompts[key] !== 'object') {
        prompts[key] = {
            'type': 'string',
            'default': val
        };
    } else {
        prompts[key]['default'] = val;
    }
}
